"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.Day = void 0;
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var _react = require("react");
var _View = require("@instructure/ui-view/lib/View");
var _AccessibleContent = require("@instructure/ui-a11y-content/lib/AccessibleContent");
var _omitProps = require("@instructure/ui-react-utils/lib/omitProps.js");
var _callRenderProp = require("@instructure/ui-react-utils/lib/callRenderProp.js");
var _getElementType = require("@instructure/ui-react-utils/lib/getElementType.js");
var _testable = require("@instructure/ui-testable/lib/testable.js");
var _emotion = require("@instructure/emotion");
var _styles = _interopRequireDefault(require("./styles"));
var _theme = _interopRequireDefault(require("./theme"));
var _props = require("./props");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
const _excluded = ["children", "label", "interaction", "isOutsideMonth", "isSelected", "isToday", "onClick", "onKeyDown", "as", "styles"];
var _dec, _dec2, _class, _Day;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
/**
---
parent: Calendar
id: Calendar.Day
---
 **/
let Day = exports.Day = (_dec = (0, _emotion.withStyle)(_styles.default, _theme.default), _dec2 = (0, _testable.testable)(), _dec(_class = _dec2(_class = (_Day = class Day extends _react.Component {
  constructor(...args) {
    super(...args);
    this.ref = null;
    this.handleClick = event => {
      const _this$props = this.props,
        onClick = _this$props.onClick,
        date = _this$props.date;
      if (typeof onClick === 'function') {
        onClick(event, {
          date
        });
      }
    };
    this.handleKeyDown = event => {
      const _this$props2 = this.props,
        onKeyDown = _this$props2.onKeyDown,
        date = _this$props2.date;
      if (typeof onKeyDown === 'function') {
        onKeyDown(event, {
          date
        });
      }
    };
    this.handleElementRef = el => {
      const elementRef = this.props.elementRef;
      this.ref = el;
      if (typeof elementRef === 'function') {
        elementRef(el);
      }
    };
  }
  componentDidMount() {
    var _this$props$makeStyle, _this$props3;
    (_this$props$makeStyle = (_this$props3 = this.props).makeStyles) === null || _this$props$makeStyle === void 0 ? void 0 : _this$props$makeStyle.call(_this$props3, this.makeStylesVariables);
  }
  componentDidUpdate() {
    var _this$props$makeStyle2, _this$props4;
    (_this$props$makeStyle2 = (_this$props4 = this.props).makeStyles) === null || _this$props$makeStyle2 === void 0 ? void 0 : _this$props$makeStyle2.call(_this$props4, this.makeStylesVariables);
  }
  get makeStylesVariables() {
    return {
      isDisabled: this.isDisabled
    };
  }
  get isDisabled() {
    const interaction = this.props.interaction;
    return interaction === 'disabled';
  }
  get elementType() {
    const as = this.props.as;
    return as || (0, _getElementType.getElementType)(Day, this.props);
  }
  shouldApplyAriaSelected() {
    const role = this.props.role;
    return !!role && ['option', 'gridcell'].indexOf(role) > -1;
  }
  render() {
    const _this$props5 = this.props,
      children = _this$props5.children,
      label = _this$props5.label,
      interaction = _this$props5.interaction,
      isOutsideMonth = _this$props5.isOutsideMonth,
      isSelected = _this$props5.isSelected,
      isToday = _this$props5.isToday,
      onClick = _this$props5.onClick,
      onKeyDown = _this$props5.onKeyDown,
      as = _this$props5.as,
      styles = _this$props5.styles,
      props = (0, _objectWithoutProperties2.default)(_this$props5, _excluded);
    const elementType = this.elementType,
      isDisabled = this.isDisabled;
    const passthroughProps = _View.View.omitViewProps((0, _omitProps.omitProps)(props, Day.allowedProps), Day);
    return (0, _jsxRuntime.jsx)(_View.View, {
      ...passthroughProps,
      as: elementType,
      css: styles === null || styles === void 0 ? void 0 : styles.calendarDay,
      display: "inline-block",
      margin: "xxx-small",
      borderWidth: "none",
      borderColor: "transparent",
      background: "transparent",
      cursor: elementType === 'button' || elementType === 'a' ? isDisabled ? 'not-allowed' : 'pointer' : 'auto',
      disabled: isDisabled,
      "aria-current": isToday ? 'date' : void 0,
      "aria-selected": this.shouldApplyAriaSelected() ? isSelected ? 'true' : 'false' : void 0,
      onClick: onClick && this.handleClick,
      onKeyDown: onKeyDown && this.handleKeyDown,
      elementRef: this.handleElementRef,
      children: (0, _jsxRuntime.jsx)("span", {
        css: styles === null || styles === void 0 ? void 0 : styles.day,
        children: (0, _jsxRuntime.jsx)(_AccessibleContent.AccessibleContent, {
          alt: label,
          children: (0, _callRenderProp.callRenderProp)(children)
        })
      })
    });
  }
}, _Day.displayName = "Day", _Day.componentId = 'Calendar.Day', _Day.propTypes = _props.propTypes, _Day.allowedProps = _props.allowedProps, _Day.defaultProps = {
  interaction: 'enabled',
  isSelected: false,
  isToday: false,
  isOutsideMonth: false
}, _Day)) || _class) || _class);
var _default = exports.default = Day;