import type { AsElementType, PropValidators, CalendarDayTheme, OtherHTMLAttributes } from '@instructure/shared-types';
import type { WithStyleProps, ComponentStyle } from '@instructure/emotion';
import { KeyboardEvent, MouseEvent } from 'react';
import type { ViewProps } from '@instructure/ui-view';
import { Renderable } from '@instructure/shared-types';
type CalendarDayOwnProps = {
    /**
     * The rendered representation of the corresponding date.
     */
    children?: Renderable;
    /**
     * An ISO 8601 formatted string representing the date corresponding to
     * this `<Calendar.Day />`
     */
    date: string;
    /**
     * Accessible label to provide more context for the date to assistive
     * technologies. This should consist of more than just a numerical date value.
     * It should also include the month and the year. Ex. instead of just `1`,
     * provide `1 August 2019`.
     */
    label: string;
    /**
     * Is the `<Calendar.Day />` disabled
     */
    interaction?: 'enabled' | 'disabled';
    /**
     * Is the `<Calendar.Day />` selected
     */
    isSelected?: boolean;
    /**
     * Is the `<Calendar.Day />` today
     */
    isToday?: boolean;
    /**
     * Is the `<Calendar.Day />` located outside the current rendered month
     */
    isOutsideMonth?: boolean;
    /**
     * Callback fired on click.
     * @param {Object} event - the click event
     * @param {Object} data - additional data
     * @param data.date - the date of the corresponding `<Calendar.Day />`
     */
    onClick?: (event: MouseEvent<ViewProps & Element>, date: {
        date: string;
    }) => void;
    /**
     * Callback fired on key down.
     * @param {Object} event - the key down event
     * @param {Object} data - additional data
     * @param data.date - the date of the corresponding `<Calendar.Day />`
     */
    onKeyDown?: (event: KeyboardEvent<ViewProps & Element>, data: {
        date: string;
    }) => void;
    /**
     * A ref function for the underlying DOM element.
     */
    elementRef?: (element: Element | null) => void;
    /**
     * the element type to render as
     */
    as?: AsElementType;
};
type CalendarDayStyleProps = {
    isDisabled: boolean;
};
type PropKeys = keyof CalendarDayOwnProps;
type AllowedPropKeys = Readonly<Array<PropKeys>>;
type CalendarDayProps = CalendarDayOwnProps & WithStyleProps<CalendarDayTheme, CalendarDayStyle> & OtherHTMLAttributes<CalendarDayOwnProps>;
type CalendarDayStyle = ComponentStyle<'calendarDay' | 'day'>;
declare const propTypes: PropValidators<PropKeys>;
declare const allowedProps: AllowedPropKeys;
export type { CalendarDayProps, CalendarDayStyleProps, CalendarDayStyle };
export { propTypes, allowedProps };
//# sourceMappingURL=props.d.ts.map